饮食男女 (豆瓣)
Description: 饮食男女电影简介和剧情介绍,饮食男女影评、图片、预告片、影讯、论坛、在线购票
Keywords: 饮食男女,飲食男女,饮食男女影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.62豆瓣电影Top250

# 饮食男女 飲食男女 (1994)

导演: 李安
编剧: 李安 / 王蕙玲 / 詹姆斯·夏慕斯
主演: 郎雄 / 杨贵媚 / 吴倩莲 / 王渝文 / 张艾嘉 / 归亚蕾 / 赵文瑄 / 陈昭荣 / 陈捷文 / 卢金城 / 唐语谦 / 洪其德 / 王瑞 / 杜满生 / 王玨 / 陈妤 / 左正芬 / 许敬民 / 聂卓晶 / 丁仲
类型: 剧情 / 家庭
制片国家/地区: 中国台湾 / 美国
语言: 汉语普通话 / 闽南语 / 湖南话
上映日期: 1994-08-03(美国)
片长: 124分钟
又名: Eat Drink Man Woman
IMDb: tt0111797
豆瓣评分
引用
9.2
584345人评价
5星
63.7%
4星
31.2%
3星
4.8%
2星
0.3%
1星
0.1%
好于 99% 家庭片
好于 99% 剧情片
想看 看过
评价:
推荐

## 饮食男女的剧情简介 · · · · · ·

台湾中国菜硕果仅存的大师老朱（郎雄）退休后，渐尝老年生活的诸多尴尬：每周日费心做出的一桌丰盛菜肴，并无将三个女儿（杨贵媚、吴倩莲、王渝文）齐齐拉到饭桌的吸引力，已经长大成人的她们，心里藏了许多比陪父亲吃饭更重要的事；多年老友的突然离世，令他在友情这块也有了缺口；而对厨师来讲最重要的味觉的丧失，则将其彻底推到人生的低谷。
三个女儿虽各忙各事，却也操心着老朱的晚年生活，计划着为其找个老伴，但她们没料到老朱早已悄无声息地谈起了“黄昏恋”。吃惊过后，老朱最看重的继承了他做菜天赋的二女儿家倩因为自身的生活经历，对父亲、她与父亲的关系有了新的认识，而对老朱来讲更大的惊喜，还在后面。 ©豆瓣

## 饮食男女的演职员 · · · · · · ( 全部 30 )

- 李安 导演
- 郎雄 饰 Chu
- 杨贵媚 饰 朱家珍
- 吴倩莲 饰 朱家倩
- 王渝文 饰 朱家宁
- 张艾嘉 饰 锦荣

## 饮食男女的视频和图片 ······ ( 预告片1 | 视频评论1 · 添加 | 图片1563 · 添加 )

## 饮食男女的获奖情况 · · · · · · ( 全部 )

- 第67届奥斯卡金像奖
- 最佳外语片(提名)
- 李安

- 第52届金球奖
- 电影类 最佳外语片(提名)

- 第31届台北金马影展
- 金马奖 最佳剧情片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  推手

  喜宴

  东京物语

  步履不停

  雨人

  一次别离

  小偷家族

  海街日记

  一一

  岁月神偷

我要写短评

## 饮食男女的短评 · · · · · · ( 全部 146528 条 )

热门 / 最新 / 好友

### 11632 有用 阿右 看过 2012-04-21 00:38:36

看似最不能守住传统和孤独的人，坚持到最后。

### 8123 有用 薇羅尼卡 看过 2006-04-12 13:55:54

看到最后，原来是老爸最猛~~

### 902 有用 逍遥兽 看过 2007-11-12 22:01:36

归亚蕾好赞 结婚就是业障 一场牵挂 NB

### 5343 有用 Gabrielle 看过 2012-02-19 21:16:23

到现在才看这种基础款片子实在该打。吴倩莲的角色看得我如坐针毡。归亚蕾对小珊珊说：“小孩就嘴这么叼，长大必定嫁不出了。”镜头一扫吴，我才后迟钝地顿悟。问题或许甚至不在美貌和才情就在那份致命的骄傲。这才只是副线之一。李安这人坏到骨子里去了。

### 6077 有用 沙尾一姐小渡边 看过 2014-03-29 10:32:04

你个杀千刀滴老朱，我以为你要勾引我，原来你是要拐走我滴女儿！

> 更多短评 146528条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 饮食男女的影评 · · · · · · ( 全部 2338 条 )

热门 / 最新 / 好友
amei 2007-06-18 09:22:34

## 父女之间

这篇影评可能有剧透

希腊神话中有一个著名的故事：弑父娶母。弗洛伊德由此将男孩的恋母情结命名为“俄狄浦斯情结”，相信大家都不会陌生。而与它相对应的女孩情结被称之为“埃勒克特拉情结”。 　　埃勒克特拉是古希腊参与杀害母亲的神话人物。“埃勒克特拉情结”概括的是女性在儿童时期形成的恋... (展开)
8130 492 493回应 收起
叶阳心理工作室 2011-04-09 12:59:01

## 家庭爱的禁忌：乱伦情感——影片《饮食男女》心理解读

这篇影评可能有剧透

撰文：北京慧泽心洲心理专家、主任咨询师 叶艳 孔子曰：“饮食男女，人之大欲也”。意思是说人的生命无外为两件事：饮食和男女，即吃和性。导演李安影片名《饮食男女》，即是借用孔子这句诗意，来表达一个家庭中的爱欲纠结。影片讲述一个单亲家庭（中年丧偶的父亲，历经16年... (展开)
6366 191 466回应 收起
隆咚锵 2009-01-18 23:07:21

## 我是很勤奋的饮食女

我是那种不喜欢《卧虎藏龙》，也不喜欢《断背山》，却喜欢《喜宴》，《推手》，《饮食男女》的观众。我很喜欢看这种故事性很强的电影。在李安这三部电影中，有异国恋，同性恋，老少恋，未婚先孕，大龄剩女，基本上，李安早在1994年以前就把当代社会的核心男女问题都讨论完毕了... (展开)
2604 269 230回应 收起
贝塔先生 2008-08-14 00:52:39

## 乐观向上的吃货

没人再有耐心读文字的时代 我想在每个周二晚十点，讲一个荒唐的故事，欢迎关注 －－－－－－－－－广告结束，我让路－－－－－－－－－－－ 朱老爷子和老兄弟喝了酒，颤颤悠悠走在过道里，说：“饮食男女，人之大欲。不想也难，忙活一辈子，就为了这个……想了气人，好滋味儿谁... (展开)
1613 271 133回应 收起
veronique 2007-11-03 17:57:43

## 其他-----李安还是坏人

自从他在《喜宴》里，狡诈地让巍巍莫名其妙当了一对小gay情侣的代孕母，还硬塞给她一份“皆大欢喜”的心甘情愿，又在《饮食男女》之末，让娶了年轻小姑娘的老头枯树又抽嫩枝之后——我就根深蒂固地认为，李安是坏人。 如同有一次师姐说到：《断背山》当然是一部好电影，但却是... (展开)
1340 357 338回应 收起
lisa|离 2011-06-29 00:59:52

## 饭桌上做爱

其实今儿是刚看完喜宴的一天，喜宴，饮食男女，我都看了很多遍。照理说得再看几遍推手的，但我始终觉得推手相较这两部，始终有点儿显弱。 李安的细节精致到让人咋舌，也正是如此可让我安心的乐此不疲的一遍遍看这部饮食男女。 饮食男女，人之大欲存焉。像是难得一回的饭桌上做... (展开)
1010 128 51回应 收起
张晚禾 2012-09-23 20:36:02

## 《饮食男女》情节结构分析

这篇影评可能有剧透

《饮食男女》情节结构分析 （拉片笔记） 亚里士多德在《诗学》中指出，一个剧本必须要有开端、中部和结尾。虽然这是一个不证自明的命题，但却是不容轻视的规律。在叙事体的戏剧和影片中，一部剧本分成五部分：开端、展开、递进、高潮、结尾。即：开场（介绍情境、设置悬念、例... (展开)
847 30 53回应 收起
麦 2006-02-09 15:24:33

## 《饮食男女》-男欢女爱,滋味万千

这篇影评可能有剧透

我知道结局的,很久前就知道，就是一直没看。 懒洋洋地看着十多年前的片子，居然慢慢微笑、兴奋起来。是的，美食、感情当然是有趣，但是片子背后的那个会心笑容，更有意思。李安，果然不简单。 中国文化中的微妙滋味，拿捏地到位、入味。这就高了很多聪明人一筹。小细节、小角... (展开)
577 27 69回应 收起
阿依达 2009-09-09 18:03:44

## 一部好电影，抵得过十颗通心丸！

昨天看过了李安导演的老片《饮食男女》，好不痛快！ 人家说，现在的作家、导演中，中国味十足的，正经不是大陆人，而是我们的港澳同胞们。这可一点不假。你看看李碧华的《胭脂扣》、《霸王别姬》，李安的《推手》、《喜宴》、《色戒》，杨凡的《游园惊梦》，王家卫的《花样年... (展开)
525 32 39回应 收起

> 更多影评 2338篇

添加新讨论

## 讨论区 · · · · · ·

电影看得很懵，台湾人婚恋观和大陆的确不一样 | 来自Daven | 45 回应 | 2022-11-24 19:22:07
《饮食男女》有国语版的吗？ | 来自eiu |  | 2022-11-21 23:20:08
哪里可以看呀~ | 来自化莉莉 | 13 回应 | 2022-11-21 03:02:12
其实老朱后来宣布和锦容在一起的时候，女儿们的反... | 来自Vicky_maaa | 7 回应 | 2022-11-16 17:11:01
我觉得吴倩莲像汤唯。。。 | 来自a wild snowman | 169 回应 | 2022-11-15 01:29:39

> 去这部影片的讨论区（全部335条）

## 关于《饮食男女》的问题 · · · · · · ( 全部53个 )

- 为什么要让亡妻的样貌和二女儿一样？ 15人回答
- 大女儿为什么要编出和李凯有一段关系的故事？ 18人回答

> 全部53个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 电影上的“三部曲”系列~~ (Black Tulip)
- 独立女性必看电影 (aristos)
- 【♨大未的私房菜馆♨】 (洋)

## 谁在看这部电影 · · · · · ·

- 自由
  3分钟前 想看
- 沉默是最好的
  7分钟前 看过
- cedar
  8分钟前 看过

837389人看过 / 334596人想看

订阅饮食男女的评论:
feed: rss 2.0